function addScapScripts() {
	console.log('Adding SCAP scripts for WebOS version ' + window.webOSVersion);

	switch (window.webOSVersion) {
		case '3.0':
		case '3.2':
		case '4.0':
		case '4.1':
		case '6.0.0':
			var scapFiles = [
				'configuration.js',
				'deviceInfo.js',
				'inputSource.js',
				'power.js',
				'signage.js',
				'sound.js',
				'storage.js',
				'video.js',
				'security.js',
				'time.js',
				'utility.js'
			];

			var webOSScapVersion = {
				'3.0': '1.4.5',
				'3.2': '1.5.10',
				'4.0': '1.6.5',
				'4.1': '1.7.4',
				'6.0.0': '1.8.0'
			};

			addNextOrStart(webOSScapVersion[window.webOSVersion], scapFiles, 0);

			break;
		default:
			console.error('- No SCAP scripts defined for this version');
			break;
	}
}

function addNextOrStart(webOsPath, scapFiles, index) {
	var scriptPath = './webos/cordova-cd/' + webOsPath + '/' + scapFiles[index];

	console.log('- Loading ' + scriptPath);

	addScript(scriptPath, function () {
		var nextIndex = index + 1;

		if (nextIndex >= scapFiles.length) {
			var retry = function () {
				console.log('Retrying in 5 seconds');

				setTimeout(function () {
					getDeviceInfoAndStart();
				}, 5000);
			};

			var getDeviceInfoAndStart = function () {
				try {
					var deviceInfo = new DeviceInfo();

					deviceInfo.getPlatformInfo(
						function () {
							startApplication();
						},
						function (error) {
							console.error('Cannot get platform information, so not able to start application', error);

							retry();
						}
					);
				} catch (error) {
					console.error(error);

					retry();
				}
			};

			getDeviceInfoAndStart();
		} else {
			addNextOrStart(webOsPath, scapFiles, nextIndex);
		}
	});
}

// WebOS < 6.0
function requestWebOsVersionByCustomJS() {
	try {
		new Custom().Signage.getwebOSVersion(
			function (result) {
				window.webOSVersion = result.webOSVersion;

				addScapScripts();
			},
			function (error) {
				console.error('Failed to get WebOS version by CustomJS, trying IDCAP in a moment. ([' + error.errorCode + '] ' + error.errorText + ')');

				setTimeout(function () {
					addScript('./webos/cordova-cd/idcap.js', function () {
						requestWebOsVersionByIDCAP();
					});
				}, 3000);
			}
		);
	} catch (error) {
		console.error(error);

		setTimeout(function () {
			requestWebOsVersion();
		}, 5000);
	}
}

// WebOS >= 6.0
function requestWebOsVersionByIDCAP() {
	try {
		idcap.request('idcap://configuration/property/get', {
			parameters: {
				key: 'webos_version'
			},
			onSuccess: function (result) {
				window.webOSVersion = result.value;

				addScapScripts();
			},
			onFailure: function (error) {
				console.error('Failed to get WebOS version by IDCAP too. Cannot proceed now. (' + error.errorMessage + ')');

				setTimeout(function () {
					requestWebOsVersion();
				}, 5000);
			}
		});
	} catch (error) {
		console.error(error);

		setTimeout(function () {
			requestWebOsVersion();
		}, 5000);
	}
}

function requestWebOsVersion() {
	try {
		requestWebOsVersionByCustomJS();
	} catch (error) {
		console.error('Failed to get determine WebOS version, retrying in 5 seconds', error);

		setTimeout(function () {
			requestWebOsVersion();
		}, 5000);
	}
}

requestWebOsVersion();
